# Filesystems

As soon as you have access to ZIH systems, you have to manage your data. Several filesystems are
available. Each filesystem serves for special purpose according to their respective capacity,
performance and permanence.

## Work Directories

!!! note "End of life of `scratch` and `ssd`"

    The filesystem `/lustre/scratch` and `/lustre/ssd` will be turned off on January 3 2024 for good
    (no data access afterwards!).

    The `/beegfs` filesystem will remain available to
    [Alpha Centauri](../jobs_and_resources/hardware_overview_2023.md#alpha-centauri-amd-rome-cpus-nvidia-a100)
    and
    [Power9](../jobs_and_resources/hardware_overview_2023.md#ibm-power9-nodes-for-machine-learning)
    users only.

    All others need to migrate your data to Barnard’s new file system `/horse`. Please follow these
    detailed instruction on how to [migrate to Barnard](../jobs_and_resources/migration_to_barnard.md).

TODO Where to add this information:
All clusters will have access to these shared parallel filesystems:

| Filesystem | Usable directory | Type | Capacity | Purpose |
| --- | --- | --- | --- | --- |
| Home | `/home` | Lustre | quota per user: 20 GB | permanent user data |
| Project | `/projects` | Lustre | quota per project | permanent project data |
| Scratch for large data / streaming | `/data/horse` | Lustre | 20 PB |  |
<!--end-->

| Filesystem  | Usable directory  | Capacity | Availability | Backup | Remarks                                                                                                                                                         |
|:------------|:------------------|:---------|:-------------|:-------|:----------------------------------------------------------------------------------------------------------------------------------------------------------------|
| `Lustre`    | `/scratch/`       | 4 PB     | global       | No     | Only accessible via [Workspaces](workspaces.md). Not made for billions of files!                                                                                   |
| `Lustre`    | `/lustre/ssd`     | 40 TB    | global       | No     | Only accessible via [Workspaces](workspaces.md). For small I/O operations                                                                                          |
| `BeeGFS`    | `/beegfs/global0` | 280 TB   | global       | No     | Only accessible via [Workspaces](workspaces.md). Fastest available filesystem, only for large parallel applications running with millions of small I/O operations |
| `BeeGFS`    | `/beegfs/global1` | 232 TB   | global       | No     | Only accessible via [Workspaces](workspaces.md). Fastest available filesystem, only for large parallel applications running with millions of small I/O operations |
| `ext4`      | `/tmp`            | 95 GB    | local        | No     | is cleaned up after the job automatically  |

## Recommendations for Filesystem Usage

To work as efficient as possible, consider the following points

- Save source code etc. in `/home` or `/projects/...`
- Store checkpoints and other temporary data in `/scratch/ws/...`
- Compilation in `/dev/shm` or `/tmp`

Getting high I/O-bandwidth

- Use many clients
- Use many processes (writing in the same file at the same time is possible)
- Use large I/O transfer blocks

## Cheat Sheet for Debugging Filesystem Issues

Users can select from the following commands to get some idea about
their data.

### General

For the first view, you can use the command `df`.

```console
marie@login$ df
```

Alternatively, you can use the command `findmnt`, which is also able to report space usage
by adding the parameter `-D`:

```console
marie@login$ findmnt -D
```

Optionally, you can use the parameter `-t` to specify the filesystem type or the parameter `-o` to
alter the output.

!!! important

    Do **not** use the `du`-command for this purpose. It is able to cause issues
    for other users, while reading data from the filesystem.
